==> haskell-recaptcha-0.1.0.4-192-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recaptcha.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 recaptcha
version:              0.1.0.4
visibility:           public
id:                   recaptcha-0.1.0.4-38YeecoOeuAArZNU4a5n4U
key:                  recaptcha-0.1.0.4-38YeecoOeuAArZNU4a5n4U
license:              BSD-3-Clause
copyright:            (c) 2008 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             http://github.com/jgm/recaptcha/tree/master
synopsis:
    Functions for using the reCAPTCHA service in web applications.

description:
    reCAPTCHA (https://www.google.com/recaptcha/intro/) is a
    service that provides captchas for preventing automated
    spam in web applications.
    recaptcha-hs provides functions for using reCAPTCHA in Haskell
    web applications.

category:             Network
abi:                  af399a7d2d893d538cc35db279fae131
exposed:              True
exposed-modules:      Network.Captcha.ReCaptcha
import-dirs:          /usr/lib/ghc-9.2.8/site-local/recaptcha-0.1.0.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/recaptcha-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recaptcha
hs-libraries:         HSrecaptcha-0.1.0.4-38YeecoOeuAArZNU4a5n4U
depends:
    HTTP-4000.4.1-7Xb6LPAjbKTJSzmSxRek1P base-4.16.4.0
    network-3.1.4.0-9VcJfHdcvDFHTEtyJROzpl
    network-uri-2.6.4.2-70RFAxlx3mCGDwOqwoqFaO xhtml-3000.2.2.1

haddock-interfaces:   /usr/share/doc/haskell-recaptcha/html/recaptcha.haddock
haddock-html:         /usr/share/doc/haskell-recaptcha/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-recaptcha-0.1.0.4-194-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recaptcha.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 recaptcha
version:              0.1.0.4
visibility:           public
id:                   recaptcha-0.1.0.4-DHR10tYbSDeBwJrT72zzhj
key:                  recaptcha-0.1.0.4-DHR10tYbSDeBwJrT72zzhj
license:              BSD-3-Clause
copyright:            (c) 2008 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             http://github.com/jgm/recaptcha/tree/master
synopsis:
    Functions for using the reCAPTCHA service in web applications.

description:
    reCAPTCHA (https://www.google.com/recaptcha/intro/) is a
    service that provides captchas for preventing automated
    spam in web applications.
    recaptcha-hs provides functions for using reCAPTCHA in Haskell
    web applications.

category:             Network
abi:                  fa8daf5f2d6f91b8fdbaf039d7576d07
exposed:              True
exposed-modules:      Network.Captcha.ReCaptcha
import-dirs:          /usr/lib/ghc-9.2.8/site-local/recaptcha-0.1.0.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/recaptcha-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recaptcha
hs-libraries:         HSrecaptcha-0.1.0.4-DHR10tYbSDeBwJrT72zzhj
depends:
    HTTP-4000.4.1-DcUjuHzj93Bl7xT5qR0hj base-4.16.4.0
    network-3.1.4.0-FV8xnMEmZuK2exBKJ6b61i
    network-uri-2.6.4.2-HdtZVRdZv9IE2UHpLGWumM xhtml-3000.2.2.1

haddock-interfaces:   /usr/share/doc/haskell-recaptcha/html/recaptcha.haddock
haddock-html:         /usr/share/doc/haskell-recaptcha/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
